<p align="center">
  <img alt="Skerch Logo" src="docs/materials/assets/skerch_horizontal.svg" width="50%">
</p>

<h3 align="center">
<code>skerch</code>: Sketched matrix decompositions for PyTorch
</h3>

RTD:

[![Documentation Status](https://readthedocs.org/projects/pytorchsketchysvd/badge/?version=latest)](https://pytorchsketchysvd.readthedocs.io/en/latest/?badge=latest)

Coveralls:

[![Coverage Status](https://coveralls.io/repos/github/andres-fr/PyTorchSketchySVD/badge.svg?branch=main)](https://coveralls.io/github/andres-fr/PyTorchSketchySVD?branch=main)

Actions:

![example workflow](https://github.com/andres-fr/PyTorchSketchySVD/actions/workflows/ci/badge.svg)

PyPI

![PyPI](https://img.shields.io/pypi/v/skerch?label=pypi%20package)
![PyPI - Downloads](https://img.shields.io/pypi/dm/skerch)


### TODO:

- [ ] Finish PyPI workflow (lint, doc build, utest+cov, release)
- [x] add codecov
- [ ] README
  - [x] badges below logo (CI, coveralls, rtd, pypy-downloads?)
  - [ ] basic description and pointer to getting started
  - [ ] basic install instructions and pointer to docs
  - [ ] basic devs comment and pointer to docs
